require_relative 'spec_helper'
require 'contact_congress_parser/field'


include ContactCongressParser
describe Field do
  describe '#to_s' do
    it 'outputs a valid field' do
      field = Field.new('name')
      expect(field.to_s).to match("field(\"name\")")
    end

    it 'parses field options properly' do
      field = Field.new('state', options: ['NY', 'CA'])
      expect(field.to_s).to match("field(\"state\", options: [\"NY\", \"CA\"])")
    end

    it 'parses field options with non-standard classes properly' do
      hash = Field.new('f', options: {'Opt' => 'Opt'})
      string = Field.new('f', options: 'Opt')

      expect { hash.to_s }.to_not raise_error
      expect { string.to_s }.to_not raise_error
    end

    it 'parses required properly' do
      true_field = Field.new('f', required: 'Yes')
      false_field = Field.new('f', required: 'No')

      expect(true_field.to_s).to match("field(\"f\", required: true)")
      expect(false_field.to_s).to match("field(\"f\", required: false)")
    end
  end
end
